
# GCWD

* GCWD is a short abbreviation for 'Get connected wi-fi data'.

* This package is made to acquire all the connected wifi passwords and related data and store it in your desired place. You can even store it in your pendrive. Usually, if the location and name of the file is not specifed, the output file containing the data will be stored in the working directory with the name 'out.txt'. You can go full-on hacker mode and clone the data from a target-pc in mere seconds.

  

# Version updates:-

* 1.0.0 (Latest).

  

# Supported devices:-

* Windows.

  

# Dependencies:-

* re(regex).

  

# Installation:-

Install this tool with the *pip* command.

```pip install gcwd```

  

# Usage:-

* Run the gcwd command to generate an output file containing all the credentials.

* Data will be stored in the downloads folder by default (out.txt) of your system.

* You can specify options like:<br>-h : to get help.<br>-o : to specify output name.<br>-ol : to specify output location.

  

# run.bat:-

* Use this file to store the output file in the location of run.bat file. One usecase is that it can be used in a pendrive to get data quickly and easily (by saving run.bat in the drive itself).

  

run.bat file is as follows: (You can download it from the github.)

```
pip install gcwd
gcwd
```

  

# Developer contact:-

* Contact at raghavgohil2004@gmail.com.
